#
# Copyright (C) 2008 Jacob Peddicord <jacob@xeiso.com>
#
# This file is part of Xeiso.
#
# Xeiso is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Xeiso is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Xeiso.  If not, see <http://www.gnu.org/licenses/>.

import pyglet.resource
import pyglet.graphics
from pyglet.sprite import Sprite

import xeiso

class IconSet:
    """
    A set of icons to be drawn as a group.
    """
    
    def __init__(self, icons, x, y):
        """
        Grab resources and sprites for all of the named icons.
        """
        
        self.x = x
        self.y = y
        self._icons = []
        self.width = 0
        self.batch = pyglet.graphics.Batch()
        
        for i in icons:
            icon = {}
            icon['name'] = i
            icon['img'] = pyglet.resource.image(i+'.png')
            icon['sprite'] = Sprite(icon['img'],
                    x=self.width+self.x, y=self.y,
                    batch=self.batch)
            self.width += icon['img'].width + 8
            self._icons.append(icon)
    
    def update(self, dt):
        pass
    
    def draw(self):
        self.batch.draw()
    
