#
# Copyright (C) 2008 Jacob Peddicord <jacob@xeiso.com>
#
# This file is part of Xeiso.
#
# Xeiso is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Xeiso is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Xeiso.  If not, see <http://www.gnu.org/licenses/>.

import pyglet.resource
from pyglet.sprite import Sprite
from pyglet.window import key
from pyglet.app import exit

import xeiso
import xeiso.menus
import xeiso.package
import games
import xpkmanage
from xeiso.gui import TextLabel
from xeiso.gui.dialog import Dialog


class MenuWelcome(xeiso.menus.Menu):
    
    def __init__(self):
        """ Preload the logo """
        
        logo = pyglet.resource.image("logo.png")
        self.logo = Sprite(logo)
        self.logo.x = xeiso.win.width/2 - self.logo.width/2
        self.logo.y = xeiso.win.height - 200
        
        warn = """Welcome to Xeiso running XPK %d!

    This is an early development snapshot.
    Some features might not work correctly or at all.
    Use at your own risk.
        
    For more information visit Xeiso.com.

Press the right arrow key to continue."""
        
        self.warning = TextLabel(warn % xeiso.XPK_VERSION, font_size=16,
                multiline=True, width=600)
        self.warning.y -= 50
        
        xeiso.arrows.change(up=False, down=False, left=False, right="Continue")
    
    def draw(self):
        self.logo.draw()
        self.warning.draw()
    
    def key_down(self, keysym):
        if keysym == key.RIGHT:
            # if games are available, show them
            if xeiso.package.games:
                xeiso.sled.change_menu(games.MenuGames(), "right")
            else:
                # if not, head over to the package downloader
                xeiso.sled.change_menu(xpkmanage.MenuPackageListDownload(), "right")


class MenuOptions(xeiso.menus.Menu):
    
    def __init__(self):
        """ Preload the logo and exit text """
        
        logo = pyglet.resource.image("logo.png")
        self.logo = Sprite(logo)
        self.logo.x = xeiso.win.width/2 - self.logo.width/2
        self.logo.y = xeiso.win.height - self.logo.height - 50
        
        self.msg = TextLabel("Options")
        self.dlg_exit = None
        
        if xeiso.package.games:
            right = "Games"
            down = "Download"
        else:
            right = "Download"
            down = False
        
        xeiso.arrows.change(up=False, down=down, left="Exit", right=right)
    
    def draw(self):
        self.logo.draw()
        self.msg.draw()
        
        if self.dlg_exit:
            self.dlg_exit.draw()
    
    def update(self, dt):
        if self.dlg_exit:
            self.dlg_exit.update(dt)
    
    def key_down(self, keysym):
    
        if keysym == key.RIGHT and not xeiso.sled.animating:
            if xeiso.package.games:
                xeiso.sled.change_menu(games.MenuGames(), "right")
            else:
                xeiso.sled.change_menu(xpkmanage.MenuPackageListDownload(), "right")
            
        elif keysym == key.DOWN and not xeiso.sled.animating and not self.dlg_exit:
            if xeiso.package.games:
                xeiso.sled.change_menu(xpkmanage.MenuPackageListDownload(), "down")
            
        elif keysym == key.LEFT and not xeiso.sled.animating:
            # exit dialog
            if not self.dlg_exit:
                self.dlg_exit = Dialog("Exit?")
                xeiso.arrows.change(up=False, down=False, left="Yes", right="Return")
            else:
                pyglet.app.exit()
       
