#
# Copyright (C) 2008 Jacob Peddicord <jacob@xeiso.com>
#
# This file is part of Xeiso.
#
# Xeiso is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Xeiso is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Xeiso.  If not, see <http://www.gnu.org/licenses/>.

import os
import sys
import time
import threading
import tarfile
import urllib2
import ConfigParser


class InstallThread(threading.Thread):
    """
    Threaded way to extract a package
    """
    
    def __init__(self, package):
        self.pkg = package
        self.path = os.path.expanduser("~/.xeiso/xpk")
        self.exc = None
        threading.Thread.__init__(self, name="Thread-Install")
    
    def run(self):
        time.sleep(1)  # sleep a bit so the Install message doesn't merely flash
        try:
            f = tarfile.open(self.pkg)     
        except IOError:
            self.exc = sys.exc_info()[1]
            return
        
        f.extractall(path=self.path)
        f.close()


class PackageListThread(threading.Thread):
    """
    Thread the package list download so the interface is not blocked
    """
    
    def __init__(self):
        self.config = ConfigParser.SafeConfigParser()
        self.exc = None
        threading.Thread.__init__(self, name="Thread-PkgList")
    
    def run(self):
        try:
            pkglist = urllib2.urlopen("http://xeiso.com/xpk/?spec=2")    
        except urllib2.HTTPError:
            # object is the exec arg here
            self.exc = "%d: %s" % (sys.exc_info()[1].code, sys.exc_info()[1].msg)
            return
        except urllib2.URLError:
            # funky string errors
            self.exc = sys.exc_info()[1].reason[1]
            return
        
        try:
            self.config.readfp(pkglist)
        except:
            self.exc = "No packages found."
            return
        finally:
            pkglist.close()


class PackageDownloadThread(threading.Thread):
    """
    Thread the package download so the interface is not blocked
    """
    
    def __init__(self, url):
        self.exc = None
        self.url = url
        self.fname = "/tmp/xeiso-" + os.path.basename(url)
        threading.Thread.__init__(self, name="Thread-PkgDownload")
    
    def run(self):
        try:
            pkg = urllib2.urlopen(self.url)  
        except urllib2.HTTPError:
            # object is the exec arg here
            self.exc = "%d: %s" % (sys.exc_info()[1].code, sys.exc_info()[1].msg)
            return
        except urllib2.URLError:
            # funky string errors
            self.exc = sys.exc_info()[1].reason[1]
            return
        
        wfile = open(self.fname, 'wb')
        data = pkg.read()
        wfile.write(data)
        pkg.close()
        wfile.close()

