#
# Copyright (C) 2008 Jacob Peddicord <jacob@xeiso.com>
#
# This file is part of Xeiso.
#
# Xeiso is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Xeiso is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Xeiso.  If not, see <http://www.gnu.org/licenses/>.

from pyglet.gl import *

import xeiso


class Slider:
    """
    Controls the actions and drawing of the animated menu systems
    """
    
    def __init__(self, menu):
        """
        Set some variables and load the initial menu
        """
        
        self.menu = menu        # currently displayed menu
        self.menu_ = None       # exiting menu if in animation
        
        self.animating = False  # False, or a direction
        self.percent = 0.0      # animation percent complete
        self.offset = 0         # pixel value
        
        self.tx = 0.0           # GL x translation
        self.ty = 0.0           # GL y translation
        self.tx_ = 0.0          # GL x translation (exiting)
        self.ty_ = 0.0          # GL y translation (exiting)
        
    def draw(self):
        """
        Draw the current menu, or both if animating
        """
        
        glLoadIdentity()
        
        if self.animating != False:
            # draw current (entering) menu
            glTranslatef(self.tx, self.ty, 0.0)
            self.menu.draw()
            # draw exiting menu
            glLoadIdentity()
            glTranslatef(self.tx_, self.ty_, 0.0)
            self.menu_.draw()
        else:
            self.menu.draw()
    
    def update(self, dt):
        """
        Update slider animations as well as individual menu updates
        """
        
        self.menu.update(dt)
        
        if self.animating != False:
            self.menu_.update(dt)
        
            # slider animations
            self.percent += 0.14
            
            if self.animating == "right" or self.animating == "left":
                self.offset = self.percent * xeiso.win.width 
                
                if self.animating == "right":
                    self.tx = xeiso.win.width - self.offset
                    self.tx_ = -self.offset
                if self.animating == "left":
                    self.tx = self.offset - xeiso.win.width
                    self.tx_ = self.offset
                
            elif self.animating == "up" or self.animating == "down":
                self.offset = self.percent * xeiso.win.height
                
                if self.animating == "up":
                    self.ty = xeiso.win.height - self.offset
                    self.ty_ = -self.offset
                if self.animating == "down":
                    self.ty = self.offset - xeiso.win.height
                    self.ty_ = self.offset
        
            # stop the animation if 100% done
            if self.percent >= 1.0:
                self.percent = 0.0
                self.animating = False
                self.tx = self.tx_ = self.ty = self.ty_ = 0.0
                
                # send out an animation done signal to the menu
                self.menu.transition_done()
        
    
    def change_menu(self, newmenu, anim_direction):
        """
        Change active menus and trigger animation
        anim_direction is the direction the new menu is coming *from*, not
        moving *to*.
        """
        
        # don't change if still animating
        if self.animating != False:
            return False
        
        self.menu_ = self.menu
        self.menu = newmenu
        
        self.animating = anim_direction
        
        # trigger a gui arrow click animation
        xeiso.arrows.click(anim_direction)
        
        # self update to avoid single-frame flicker after change
        self.update(0)
        
        return True
